@@ -32,11 +32,11 @@ HPC::Runner - HPC Runner::Slurm, Runner::MCE and Runner::Threads base class
 
 =head1 VERSION
 
-Version 0.01
+Version 2.4.2
 
 =cut
 
-our $VERSION = '2.42';
+our $VERSION = '2.43';
 
 =head1 SYNOPSIS
 
@@ -255,6 +255,28 @@ has 'logname' => (
     default => 'hpcrunner_logs',
 );
 
+=head2 process_table
+
+We also want to write all cmds and exit codes to a table
+
+=cut
+
+has 'process_table' => (
+    isa => 'Str',
+    is => 'rw',
+
+    handles => {
+        add_process_table => 'append',
+        prepend_process_table => 'prepend',
+        clear_process_table => 'clear',
+    },
+    default => sub {
+        my $self = shift;
+        return $self->logdir."/process_table.md"
+    },
+    lazy => 1,
+);
+
 =head1 Subroutines
 
 =head2 set_logdir
@@ -267,6 +289,9 @@ sub set_logdir{
     my $self = shift;
 
     my $logdir;
+    use Carp::Always;
+    use Data::Dumper;
+    #confess(Dumper($self));
     $logdir = $self->outdir."/".$self->logname."_".$self->set_logfile;
 
     $DB::single=2;
@@ -374,23 +399,52 @@ sub _log_commands {
     #same here
     my $dt1 = DateTime->now();
 
-    #Create logdir
     $DB::single=2;
 
-    #Create new log for each job
     $self->logfile($self->set_logfile);
     $self->prepend_logfile("CMD".$self->counter."_PID_$pid"."_DT_");
     $DB::single=2;
 
-    #my $logger = $self->init_log;
     $self->command_log($self->init_log);
 
+    my($cmdpid, $exitcode) = $self->log_job;
+
+    $self->log_messages("debug", "Finishing job ".$self->counter." with ExitCode $exitcode", $cmdpid);
+
+    my $dt2 = DateTime->now();
+    my $duration = $dt2 - $dt1;
+    my $format = DateTime::Format::Duration->new(
+        pattern => '%Y years, %m months, %e days, %H hours, %M minutes, %S seconds'
+    );
+
+    $self->log_messages("info", "Total execution time ".$format->format_duration($duration), $cmdpid);
+
+    $self->log_table($cmdpid, $exitcode, $format->format_duration($duration));
+    return $exitcode;
+}
+
+##TODO extend this in HPC-Runner-Web for ENV tags
+sub log_table {
+    my $self = shift;
+    my $cmdpid = shift;
+    my $exitcode = shift;
+    my $duration = shift;
+
+    open(my $pidtablefh, ">>".$self->process_table) or die print "Couldn't open process file $!\n";
+
+    print $pidtablefh "### $self->{cmd}\n";
+    print $pidtablefh <<EOF;
+|$cmdpid|$exitcode|$duration|
+
+EOF
+}
+
+sub log_job {
+    my $self = shift;
+
     #Start running job
     my ($infh,$outfh,$errfh);
     $errfh = gensym(); # if you uncomment this line, $errfh will
-    # never be initialized for you and you
-    # will get a warning in the next print
-    # line.
     my $cmdpid;
     eval{
         $cmdpid = open3($infh, $outfh, $errfh, $self->cmd);
@@ -411,9 +465,6 @@ sub _log_commands {
 
     $DB::single=2;
 
-# now our child is running, happily printing to
-# its stdout and stderr (our $outfh and $errfh).
-
     my $sel = new IO::Select; # create a select object
     $sel->add($outfh,$errfh); # and add the fhs
 
@@ -445,19 +496,7 @@ sub _log_commands {
     waitpid($cmdpid, 1);
     my $exitcode = $?;
 
-    $DB::single=2;
-
-    $self->log_messages("debug", "Finishing job ".$self->counter." with ExitCode $exitcode", $cmdpid);
-
-    my $dt2 = DateTime->now();
-    my $duration = $dt2 - $dt1;
-    my $format = DateTime::Format::Duration->new(
-        pattern => '%Y years, %m months, %e days, %H hours, %M minutes, %S seconds'
-    );
-
-    $self->log_messages("info", "Total execution time ".$format->format_duration($duration), $cmdpid);
-
-    return $exitcode;
+    return($cmdpid, $exitcode);
 }
 
 sub log_messages{
@@ -492,8 +531,7 @@ automatically be notified of progress on your bug as I make changes.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Runner::Init
-
+perldoc HPC::Runner
 
 You can also look for information at:
 
